@@ -10,19 +10,48 @@ use base   qw/Reddit::Client::VotableThing/;
 use fields qw/
 approved_by
 author
+author_flair_background_color
 author_flair_css_class
+author_flair_richtext
+author_flair_template_id
 author_flair_text
+author_flair_text_color
+author_flair_type
+author_fullname
+author_patreon_flair
+author_premium
+awarders
+banned_at_utc
 banned_by
+can_gild
 can_mod_post
+category
 clicked
+content_categories
+contest_mode
 created
 created_utc
 crosspost_parent
+discussion_type
+distinguished
 domain
+gilded
+gildings
 hidden
+hide_score
+is_crosspostable
+is_meta
+is_reddit_media_domain
+is_robot_indexable
 is_self
+is_video
+link_flair_background_color
 link_flair_css_class
+link_flair_richtext
+link_flair_template_id
 link_flair_text
+link_flair_text_color
+link_flair_type
 locked
 media
 media_embed
@@ -32,20 +61,39 @@ num_comments
 num_reports
 over_18
 permalink
+pwls
 quarantine
+removal_reason
 removed
+removed_by
+removed_by_category
+report_reasons
 saved
+secure_media
 selftext
 selftext_html
+send_replies
 spam
 spoiler
+steward_reports
 stickied
 subreddit
 subreddit_id
+subreddit_name_prefixed
+subreddit_subscribers
+subreddit_type
+suggested_sort
 thumbnail
+thumbnail_height
+thumbnail_width
 title
+total_awards_received
 url
 user_reports
+view_count
+visited
+whitelist_status
+wls
 /;
 
 use constant type => "t3";
